==> tesseract_core-0.8.2.tar.gz: tesseract_core-0.8.2/inject_runtime_pyproject.py <==
"""Custom hook to inject config from runtime pyproject.toml into the main pyproject.toml.

This allows us to specify runtime dependencies and scripts in only one place.
"""

from pathlib import Path

import toml
from hatchling.metadata.plugin.interface import MetadataHookInterface

RUNTIME_PYPROJECT_PATH = "tesseract_core/runtime/meta/pyproject.toml"

BASE_OPTIONAL_DEPS = {
    "docs": [
        "sphinx",
        "sphinx_autodoc_typehints",
        "furo",
        "myst-parser",
        "sphinx_click",
        "autodoc_pydantic",
        "sphinx_design",
        "sphinx_copybutton",
        "sphinxext_opengraph",
        "tesseract-core[runtime]",
    ],
    "dev": [
        "fastapi",
        "httpx",  # required by fastapi test client
        "jsf",
        "requests",
        "numpy",
        "pre-commit",
        "pytest",
        "pytest-cov",
        "pytest-mock",
        "moto[server]",
        "aiobotocore>=2.19.0",  # without this pip dependency resolution fails
        "typeguard",
        # also add all other extras here
        "tesseract-core[runtime]",
        "tesseract-core[docs]",
    ],
    "runtime": [],
}

BASE_SCRIPTS = {
    "tesseract": "tesseract_core.sdk.cli:entrypoint",
}


class RuntimeDepenencyHook(MetadataHookInterface):
    PLUGIN_NAME = "runtime-deps"

    def update(self, metadata):
        runtime_metadata = toml.load(Path(self.root) / RUNTIME_PYPROJECT_PATH)
        metadata["optional-dependencies"] = {
            **BASE_OPTIONAL_DEPS,
            "runtime": runtime_metadata["project"]["dependencies"],
        }
        metadata["scripts"] = {**BASE_SCRIPTS, **runtime_metadata["project"]["scripts"]}
        return metadata

==> tesseract_core-0.8.5.tar.gz: tesseract_core-0.8.5/inject_runtime_pyproject.py <==
"""Custom hook to inject config from runtime pyproject.toml into the main pyproject.toml.

This allows us to specify runtime dependencies and scripts in only one place.
"""

from pathlib import Path

import toml
from hatchling.metadata.plugin.interface import MetadataHookInterface

RUNTIME_PYPROJECT_PATH = "tesseract_core/runtime/meta/pyproject.toml"

BASE_OPTIONAL_DEPS = {
    "docs": [
        "sphinx",
        "sphinx_autodoc_typehints",
        "furo",
        "myst-parser",
        "sphinx_click",
        "autodoc_pydantic",
        "sphinx_design",
        "sphinx_copybutton",
        "sphinxext_opengraph",
        "tesseract-core[runtime]",
    ],
    "dev": [
        "fastapi",
        "httpx",  # required by fastapi test client
        "jsf",
        "requests",
        "numpy",
        "pre-commit",
        "pytest",
        "pytest-cov",
        "pytest-mock",
        "moto[server]",
        "aiobotocore>=2.19.0",  # without this pip dependency resolution fails
        "typeguard",
        # also add all other extras here
        "tesseract-core[runtime]",
        "tesseract-core[docs]",
    ],
    "runtime": [],
}

BASE_SCRIPTS = {
    "tesseract": "tesseract_core.sdk.cli:entrypoint",
}


class RuntimeDepenencyHook(MetadataHookInterface):
    """Injects runtime dependencies and scripts from a separate pyproject.toml file."""

    PLUGIN_NAME = "runtime-deps"

    def update(self, metadata: dict) -> dict:
        """Update the metadata with runtime dependencies and scripts."""
        runtime_metadata = toml.load(Path(self.root) / RUNTIME_PYPROJECT_PATH)
        metadata["optional-dependencies"] = {
            **BASE_OPTIONAL_DEPS,
            "runtime": runtime_metadata["project"]["dependencies"],
        }
        metadata["scripts"] = {**BASE_SCRIPTS, **runtime_metadata["project"]["scripts"]}
        return metadata
